evaluate.moment: Evaluate a Multivariate Moment

evaluate.momentR Documentation

Evaluate a Multivariate Moment

Description

Generic method for class moment to compute the numerical value of a moment at a specified covariance matrix from the output of callmultmoments.

Usage

## S3 method for class 'moment'
evaluate(object, sigma)

Arguments

object

An object of class 'moment'.

sigma

An upper-triangular matrix of covariance terms expressed as a vector at which the moment is to be evaluated.

Details

object is normally the output of a call to callmultmoments. This is a list with the first component being the moment itself, the second component being the set of upper-triangular matrices representing the moment, and the third component containing their corresponding coefficients. This is an object of class 'moment'.

Value

The numeric value of the moment evaluated at the specified covariance matrix.

Author(s)

Kem Phillips kemphillips@comcast.net

References

\insertRef

Phillips2010symmoments

See Also

callmultmoments, and the methods simulate and toLatex from the symmoments package.

Examples

# Evaluates the moment at c(1,2,3,4) at the following covariance matrix:
#   4 2 1 1
#   2 3 1 1
#   1 1 2 1
#   1 1 1 2
evaluate(callmultmoments(c(1, 2, 3, 4)), c(4, 2, 1, 1, 3, 1, 1, 2, 1, 2))


symmoments documentation built on May 27, 2026, 9:06 a.m.