evaluate_noncentral: Evaluate a Non-Central Multivariate Moment

evaluate_noncentralR Documentation

Evaluate a Non-Central Multivariate Moment

Description

Computes the numerical value of a non-central moment at a specified mean and specified covariance matrix.

Usage

evaluate_noncentral(moment, mu, sigma, envir = "symmoments")

Arguments

moment

A vector of non-negative integers representing the non-central moment to be evaluated: X_1^{k_1} \cdots X_n^{k_n}.

mu

A vector of real numbers representing the mean vector \mu of the multivariate normal distribution.

sigma

An upper-triangular matrix of covariance terms for the multivariate normal distribution, expressed as a vector stacked by row, at which the moment is to be evaluated.

envir

A character string specifying the environment containing the central moments needed for the calculation. Defaults to 'symmoments'.

Details

This function searches the environment specified in the envir argument for the central moments required to complete the non-central expansion. The default is the symmoments environment. All even central moments less than or equal to the requested moment vector must be present. The computation will stop with an error message if any required central moment is missing from envir.

Value

The numeric value of the non-central moment evaluated at the specified mean and covariance matrix.

Author(s)

Kem Phillips kemphillips@comcast.net

References

\insertRef

Phillips2010symmoments

See Also

evaluate.moment, make.all.moments

Examples

## Not run: 
# Evaluates the expected value of X1^3 X2 X3^2 at mean c(3,4,1) 
# and at the following covariance matrix:
#    4 2 1 
#    2 3 1 
#    1 1 2 
# Note: requires all central moments up to c(3,1,2) to exist in 'symmoments'.
# If needed, run: make.all.moments(c(3,1,2))
evaluate_noncentral(c(3, 1, 2), c(3, 4, 1), c(4, 2, 1, 3, 1, 2))

# Using central moments stored instead in the global environment:
evaluate_noncentral(c(3, 1, 2), c(3, 4, 1), c(4, 2, 1, 3, 1, 2), '.GlobalEnv')

## End(Not run)


symmoments documentation built on May 27, 2026, 9:06 a.m.