multmoments: Recursive Function to Compute a Multivariate Moment

multmomentsR Documentation

Recursive Function to Compute a Multivariate Moment

Description

Called by callmultmoments to compute the representation of a multivariate normal moment using a recursive algorithm.

Usage

multmoments(moment, current.matrix, current.cell, moment.rep, row_col)

Arguments

moment

A vector c(k1, ..., kn) specifying the moment X_1^{k_1} \cdots X_n^{k_n}.

current.matrix

Upper-triangular integer matrix under consideration in the recursion.

current.cell

Cell in the current matrix under consideration in the recursion.

moment.rep

Current set of representations; multmoments adds each satisfying matrix to moment.rep.

row_col

Matrix giving rows and columns for a square matrix for each cell.

Details

Each row of the representation gives the exponents for a single product of covariance terms. For example, (1, 2, 0) represents S_{11}^1 S_{12}^2 S_{22}^0, where the S_{ij} are the covariances.

This function would normally only be called by callmultmoments.

Value

The moment representation, moment.rep, augmented with additional representations.

Author(s)

Kem Phillips kemphillips@comcast.net

References

\insertRef

Phillips2010symmoments

See Also

callmultmoments


symmoments documentation built on May 27, 2026, 9:06 a.m.