toLatex.moment: LaTeX a Multivariate Moment

toLatex.momentR Documentation

LaTeX a Multivariate Moment

Description

Computes a LaTeX representation sorted lexicographically of an object of class 'moment'.

Usage

## S3 method for class 'moment'
toLatex(object, ...)

Arguments

object

An object of class 'moment', usually the output of callmultmoments.

...

Included only for consistency with the generic function.

Details

The first element of the result is the moment expressed as an expected value (E[...] =). The remaining lines are the LaTeX representation broken at appropriate intervals for printing. (Individual terms for high dimensions will still overrun a printed line.)

Double backslashes (\\) are inserted where LaTeX requires a backslash. These can be reset to single backslashes by writing the output to a file using the standard R function writeLines.

Value

A character vector giving the LaTeX code for the symbolic moment.

Author(s)

Kem Phillips kemphillips@comcast.net

References

\insertRef

Phillips2010symmoments

See Also

callmultmoments, and the evaluate method.

Examples

toLatex(callmultmoments(c(1, 2, 3)))


symmoments documentation built on May 27, 2026, 9:06 a.m.