toLatex_noncentral: Compute a LaTeX Expression for a Non-Central Moment

toLatex_noncentralR Documentation

Compute a LaTeX Expression for a Non-Central Moment

Description

Computes a LaTeX expression for a non-central multivariate normal moment.

Usage

toLatex_noncentral(moment, envir = "symmoments")

Arguments

moment

A vector c(k1, ..., kn) specifying the moment X_1^{k_1} \cdots X_n^{k_n}.

envir

A character string specifying the environment that contains the required central moments. Defaults to 'symmoments'.

Details

All required central moment objects must already exist in the specified environment (the default is 'symmoments'). However, if only the sorted version of an unsorted moment exists in that environment, the tounsorted function will automatically be called to transform and obtain it.

Value

A character string giving the LaTeX representation of the non-central moment where X follows a multivariate normal distribution.

Author(s)

Kem Phillips kemphillips@comcast.net

References

\insertRef

Phillips2010symmoments

See Also

make.all.moments, tounsorted, callmultmoments, and the method toLatex.

Examples

## Not run: 
# Compute the LaTeX representation of the 2-dimensional non-central moment c(1,3).
# Note: This requires that all central moments up to c(1,3) have already been 
# generated in the symmoments environment using make.all.moments.
toLatex_noncentral(c(1, 3))

## End(Not run)


symmoments documentation built on May 27, 2026, 9:06 a.m.