| evaluate.moment | R Documentation |
Generic method for class moment to compute the numerical value of a
moment at a specified covariance matrix from the output of
callmultmoments.
## S3 method for class 'moment'
evaluate(object, sigma)
object |
An object of class |
sigma |
An upper-triangular matrix of covariance terms expressed as a vector at which the moment is to be evaluated. |
object is normally the output of a call to
callmultmoments. This is a list with the first component being
the moment itself, the second component being the set of upper-triangular
matrices representing the moment, and the third component containing their
corresponding coefficients. This is an object of class 'moment'.
The numeric value of the moment evaluated at the specified covariance matrix.
Kem Phillips kemphillips@comcast.net
Phillips2010symmoments
callmultmoments, and the methods simulate
and toLatex from the symmoments package.
# Evaluates the moment at c(1,2,3,4) at the following covariance matrix:
# 4 2 1 1
# 2 3 1 1
# 1 1 2 1
# 1 1 1 2
evaluate(callmultmoments(c(1, 2, 3, 4)), c(4, 2, 1, 1, 3, 1, 1, 2, 1, 2))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.