| make.all.moments | R Documentation |
Create all central moment objects of a specified or smaller size in the
symmoments environment.
make.all.moments(moment, verbose = TRUE)
moment |
A vector |
verbose |
If |
Unsorted moments (those whose exponents are not in numeric order)
are created in the symmoments environment using the
tounsorted function to transform them from their sorted counterpart.
If the symmoments environment does not exist, the user is prompted to
create it using symmoments <- new.env().
If a sorted moment does not exist, it is automatically created.
Moments of lower dimension are not created; for example, if c(2, 4) is
input, m20 is created, but m2 is not.
Naming Conventions:
Moments are named using the structure mij..l, e.g., m136.
If any exponent is greater than 9, lowercase letters, and then
uppercase letters are used. For example, m3bA represents the
moment c(3, 11, 36).
The largest single exponent allowed by this alphanumeric encoding
scheme is 9 + 26 + 26 = 61.
If an object with a name of this form already exists in the target environment
but is not an object of class "moment", it will be silently overwritten
by the new moment object.
All objects of class 'moment' up to the value given in
moment are created in the environment symmoments.
Kem Phillips kemphillips@comcast.net
Phillips2010symmoments
callmultmoments, tounsorted
## Not run:
# Create the symmoments environment if it does not exist
symmoments <- new.env()
# Compute all moments up to c(3,3)
make.all.moments(c(3, 3))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.