| multmoments | R Documentation |
Called by callmultmoments to compute the representation of a
multivariate normal moment using a recursive algorithm.
multmoments(moment, current.matrix, current.cell, moment.rep, row_col)
moment |
A vector |
current.matrix |
Upper-triangular integer matrix under consideration in the recursion. |
current.cell |
Cell in the current matrix under consideration in the recursion. |
moment.rep |
Current set of representations; |
row_col |
Matrix giving rows and columns for a square matrix for each cell. |
Each row of the representation gives the exponents for a single
product of covariance terms. For example, (1, 2, 0) represents
S_{11}^1 S_{12}^2 S_{22}^0, where the S_{ij} are the covariances.
This function would normally only be called by callmultmoments.
The moment representation, moment.rep, augmented with
additional representations.
Kem Phillips kemphillips@comcast.net
Phillips2010symmoments
callmultmoments
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.