| toLatex.moment | R Documentation |
Computes a LaTeX representation sorted lexicographically of an object of
class 'moment'.
## S3 method for class 'moment'
toLatex(object, ...)
object |
An object of class |
... |
Included only for consistency with the generic function. |
The first element of the result is the moment expressed as an
expected value (E[...] =). The remaining lines are the LaTeX
representation broken at appropriate intervals for printing. (Individual
terms for high dimensions will still overrun a printed line.)
Double backslashes (\\) are inserted where LaTeX requires a
backslash. These can be reset to single backslashes by writing the output
to a file using the standard R function writeLines.
A character vector giving the LaTeX code for the symbolic moment.
Kem Phillips kemphillips@comcast.net
Phillips2010symmoments
callmultmoments, and the evaluate method.
toLatex(callmultmoments(c(1, 2, 3)))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.