| toLatex_noncentral | R Documentation |
Computes a LaTeX expression for a non-central multivariate normal moment.
toLatex_noncentral(moment, envir = "symmoments")
moment |
A vector |
envir |
A character string specifying the environment that contains
the required central moments. Defaults to |
All required central moment objects must already exist in the
specified environment (the default is 'symmoments'). However, if only
the sorted version of an unsorted moment exists in that environment, the
tounsorted function will automatically be called to transform
and obtain it.
A character string giving the LaTeX representation of the non-central
moment where X follows a multivariate normal distribution.
Kem Phillips kemphillips@comcast.net
Phillips2010symmoments
make.all.moments, tounsorted,
callmultmoments, and the method toLatex.
## Not run:
# Compute the LaTeX representation of the 2-dimensional non-central moment c(1,3).
# Note: This requires that all central moments up to c(1,3) have already been
# generated in the symmoments environment using make.all.moments.
toLatex_noncentral(c(1, 3))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.