| tounsorted | R Documentation |
Produces an unsorted central moment object from a sorted object of class
'moment'.
tounsorted(moment, sorted.moment)
moment |
The unsorted target moment to obtain, specified in vector
form (e.g., |
sorted.moment |
A sorted object of class |
Unsorted moments are those whose exponents are not in sorted
numerical order (e.g., m312 vs m123). The unsorted moment's
representation is calculated by rearranging the rows and columns of the
sorted moment's matrices successively.
An object of class 'moment', which is a list containing the
following three components:
moment |
The input unsorted moment vector. |
representation |
A matrix containing the representation in terms of upper-triangular matrices, rearranged to match the target unsorted order. |
coefficients |
A numeric vector of the coefficients corresponding to the rows of the representation matrix. |
Kem Phillips kemphillips@comcast.net
#' \insertRefPhillips2010symmoments
multmoments, callmultmoments
# Obtain unsorted moment m312 from sorted base m123
tounsorted(c(3, 1, 2), callmultmoments(c(1, 2, 3)))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.